==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/management-toolbar/search/SearchSort.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/management-toolbar/search/SearchSort.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/drop-down', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$classnames', 'frontend-js-react-web$react', '../../../components/button/Button.es', './SearchContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Button = _interopRequireDefault(require("../../../components/button/Button.es"));

  var _SearchContext = _interopRequireDefault(require("./SearchContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var Group = _dropDown["default"].Group,
      Item = _dropDown["default"].Item,
      ItemList = _dropDown["default"].ItemList;

  var _default = function _default(_ref) {
    var columns = _ref.columns,
        disabled = _ref.disabled;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        dispatch = _useContext2[1];

    columns = columns.filter(function (column) {
      return column.sortable;
    });
    var defaultColumn = columns.find(function (column) {
      return Object.hasOwnProperty.call(column, 'asc');
    });

    if (!defaultColumn) {
      defaultColumn = _objectSpread({}, columns[0], {
        asc: true
      });
    }

    var _useState = (0, _react.useState)({
      active: false,
      asc: defaultColumn.asc,
      column: defaultColumn.key
    }),
        _useState2 = _slicedToArray(_useState, 2),
        state = _useState2[0],
        setState = _useState2[1];

    var sort = function sort(asc, column) {
      setState({
        active: false,
        asc: asc,
        column: column
      });
      dispatch({
        sort: "".concat(column, ":").concat(asc ? 'asc' : 'desc'),
        type: 'SORT'
      });
    };

    var active = state.active,
        asc = state.asc,
        column = state.column;
    return _react["default"].createElement("ul", {
      className: "navbar-nav"
    }, _react["default"].createElement("li", {
      className: "dropdown nav-item"
    }, _react["default"].createElement(_dropDown["default"], {
      active: active,
      alignmentPosition: _dropDown.Align.BottomLeft,
      onActiveChange: function onActiveChange(newActive) {
        return setState(function (prevState) {
          return _objectSpread({}, prevState, {
            active: newActive
          });
        });
      },
      trigger: _react["default"].createElement(_Button["default"], {
        className: "nav-link",
        disabled: disabled,
        displayType: "unstyled"
      }, _react["default"].createElement("span", {
        className: "navbar-breakpoint-down-d-none"
      }, Liferay.Language.get('filter-and-order'), _react["default"].createElement(_icon["default"], {
        className: "inline-item inline-item-after",
        symbol: "caret-bottom"
      })))
    }, _react["default"].createElement(ItemList, null, _react["default"].createElement(Group, {
      header: Liferay.Language.get('order-by')
    }, columns.map(function (columnObject, index) {
      return _react["default"].createElement(Item, {
        active: column === columnObject.key,
        href: "",
        key: index,
        onClick: function onClick(event) {
          event.preventDefault();
          sort(asc, columnObject.key);
        }
      }, columnObject.value);
    }))))), _react["default"].createElement("li", {
      className: "nav-item"
    }, _react["default"].createElement(_Button["default"], {
      className: (0, _classnames["default"])('nav-link', 'nav-link-monospaced', {
        'order-arrow-down-active': !asc,
        'order-arrow-up-active': asc
      }),
      disabled: disabled,
      displayType: "unstyled",
      onClick: function onClick() {
        return sort(!asc, column);
      },
      symbol: "order-arrow",
      tooltip: Liferay.Language.get('reverse-sort-direction')
    })));
  };

  exports["default"] = _default;
  //# sourceMappingURL=SearchSort.es.js.map
});
//# sourceMappingURL=SearchSort.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/management-toolbar/search/SearchSort.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/management-toolbar/search/SearchSort.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/drop-down', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$classnames', 'frontend-js-react-web$react', '../../../components/button/Button.es', './SearchContext.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Button = _interopRequireDefault(require("../../../components/button/Button.es"));

  var _SearchContext = _interopRequireDefault(require("./SearchContext.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var Group = _dropDown["default"].Group,
      Item = _dropDown["default"].Item,
      ItemList = _dropDown["default"].ItemList;

  var _default = function _default(_ref) {
    var columns = _ref.columns,
        disabled = _ref.disabled;

    var _useContext = (0, _react.useContext)(_SearchContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        dispatch = _useContext2[1];

    columns = columns.filter(function (column) {
      return column.sortable;
    });
    var defaultColumn = columns.find(function (column) {
      return Object.hasOwnProperty.call(column, 'asc');
    });

    if (!defaultColumn) {
      defaultColumn = _objectSpread({}, columns[0], {
        asc: true
      });
    }

    var _useState = (0, _react.useState)({
      active: false,
      asc: defaultColumn.asc,
      column: defaultColumn.key
    }),
        _useState2 = _slicedToArray(_useState, 2),
        state = _useState2[0],
        setState = _useState2[1];

    var sort = function sort(asc, column) {
      setState({
        active: false,
        asc: asc,
        column: column
      });
      dispatch({
        sort: "".concat(column, ":").concat(asc ? 'asc' : 'desc'),
        type: 'SORT'
      });
    };

    var active = state.active,
        asc = state.asc,
        column = state.column;
    return _react["default"].createElement("ul", {
      className: "navbar-nav"
    }, _react["default"].createElement("li", {
      className: "dropdown nav-item"
    }, _react["default"].createElement(_dropDown["default"], {
      active: active,
      alignmentPosition: _dropDown.Align.BottomLeft,
      onActiveChange: function onActiveChange(newActive) {
        return setState(function (prevState) {
          return _objectSpread({}, prevState, {
            active: newActive
          });
        });
      },
      trigger: _react["default"].createElement(_Button["default"], {
        className: "nav-link",
        disabled: disabled,
        displayType: "unstyled"
      }, _react["default"].createElement("span", {
        className: "navbar-breakpoint-down-d-none"
      }, Liferay.Language.get('filter-and-order'), _react["default"].createElement(_icon["default"], {
        className: "inline-item inline-item-after",
        symbol: "caret-bottom"
      })))
    }, _react["default"].createElement(ItemList, null, _react["default"].createElement(Group, {
      header: Liferay.Language.get('order-by')
    }, columns.map(function (columnObject, index) {
      return _react["default"].createElement(Item, {
        active: column === columnObject.key,
        href: "",
        key: index,
        onClick: function onClick(event) {
          event.preventDefault();
          sort(asc, columnObject.key);
        }
      }, columnObject.value);
    }))))), _react["default"].createElement("li", {
      className: "nav-item"
    }, _react["default"].createElement(_Button["default"], {
      className: (0, _classnames["default"])('nav-link', 'nav-link-monospaced', {
        'order-arrow-down-active': !asc,
        'order-arrow-up-active': asc
      }),
      disabled: disabled,
      displayType: "unstyled",
      onClick: function onClick() {
        return sort(!asc, column);
      },
      symbol: "order-arrow",
      tooltip: Liferay.Language.get('reverse-sort-direction')
    })));
  };

  exports["default"] = _default;
  //# sourceMappingURL=SearchSort.es.js.map
});
//# sourceMappingURL=SearchSort.es.js.map
